@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# coding=utf-8
 """A sample application for how Python scripting can provide conditional
 control flow of a cmd2 application.
 
@@ -20,30 +19,28 @@ scripts inside a cmd2 application via the run_pyscript command and the
 This application and the "examples/scripts/conditional.py" script serve as an
 example for one way in which this can be done.
 """
-import argparse
+
 import os
 
 import cmd2
-from cmd2 import (
-    ansi,
-)
+from cmd2 import ansi
 
 
 class CmdLineApp(cmd2.Cmd):
-    """ Example cmd2 application to showcase conditional control flow in Python scripting within cmd2 apps."""
+    """Example cmd2 application to showcase conditional control flow in Python scripting within cmd2 apps."""
 
-    def __init__(self):
-        # Enable the optional ipy command if IPython is installed by setting use_ipython=True
-        super().__init__(use_ipython=True)
+    def __init__(self) -> None:
+        # Set include_ipy to True to enable the "ipy" command which runs an interactive IPython shell
+        super().__init__(include_ipy=True)
         self._set_prompt()
         self.intro = 'Happy 𝛑 Day.  Note the full Unicode support:  😇 💩'
 
-    def _set_prompt(self):
+    def _set_prompt(self) -> None:
         """Set prompt so it displays the current working directory."""
         self.cwd = os.getcwd()
-        self.prompt = ansi.style(f'{self.cwd} $ ', fg='cyan')
+        self.prompt = ansi.style(f'{self.cwd} $ ', fg=ansi.Fg.CYAN)
 
-    def postcmd(self, stop: bool, line: str) -> bool:
+    def postcmd(self, stop: bool, _line: str) -> bool:
         """Hook method executed just after a command dispatch is finished.
 
         :param stop: if True, the command has indicated the application should exit
@@ -55,10 +52,10 @@ class CmdLineApp(cmd2.Cmd):
         return stop
 
     @cmd2.with_argument_list
-    def do_cd(self, arglist):
+    def do_cd(self, arglist) -> None:
         """Change directory.
-    Usage:
-        cd <new_dir>
+        Usage:
+            cd <new_dir>.
         """
         # Expect 1 argument, the directory to change to
         if not arglist or len(arglist) != 1:
@@ -80,7 +77,7 @@ class CmdLineApp(cmd2.Cmd):
         else:
             try:
                 os.chdir(path)
-            except Exception as ex:
+            except Exception as ex:  # noqa: BLE001
                 err = f'{ex}'
             else:
                 self.poutput(f'Successfully changed directory to {path}')
@@ -95,11 +92,11 @@ class CmdLineApp(cmd2.Cmd):
         # Tab complete only directories
         return self.path_complete(text, line, begidx, endidx, path_filter=os.path.isdir)
 
-    dir_parser = argparse.ArgumentParser()
+    dir_parser = cmd2.Cmd2ArgumentParser()
     dir_parser.add_argument('-l', '--long', action='store_true', help="display in long format with one item per line")
 
     @cmd2.with_argparser(dir_parser, with_unknown_args=True)
-    def do_dir(self, args, unknown):
+    def do_dir(self, _args, unknown) -> None:
         """List contents of current directory."""
         # No arguments for this command
         if unknown:
@@ -120,5 +117,6 @@ class CmdLineApp(cmd2.Cmd):
 
 if __name__ == '__main__':
     import sys
+
     c = CmdLineApp()
     sys.exit(c.cmdloop())
