@@ -1,5 +1,3 @@
-#
-# coding=utf-8
 """External test interface plugin"""
 
 from typing import (
@@ -39,7 +37,8 @@ class ExternalTestMixin(_Base):
         :param echo: Flag whether the command's output should be echoed to stdout/stderr
         :return: A CommandResult object that captures stdout, stderr, and the command's result object
         """
-        assert isinstance(self, cmd2.Cmd) and isinstance(self, ExternalTestMixin)
+        assert isinstance(self, cmd2.Cmd)
+        assert isinstance(self, ExternalTestMixin)
         try:
             self._in_py = True
 
@@ -64,7 +63,6 @@ class ExternalTestMixin(_Base):
 
         :type self: cmd2.Cmd
         """
-        # assert isinstance(self, cmd2.Cmd) and isinstance(self, ExternalTestMixin)
         for func in self._postloop_hooks:
             func()
         self.postloop()
