@@ -1,7 +1,7 @@
 import nox
 
 
-@nox.session(python=['3.5', '3.6', '3.7', '3.8', '3.9'])
-def tests(session):
+@nox.session(python=['3.9', '3.10', '3.11', '3.12', '3.13'])
+def tests(session) -> None:
     session.install('invoke', './[test]')
     session.run('invoke', 'pytest', '--junit', '--no-pty')
