@@ -1,9 +1,7 @@
-# coding=utf-8
-# flake8: noqa E302
-"""
-Test the parsing logic in parsing.py
-"""
-import attr
+"""Test the parsing logic in parsing.py"""
+
+import dataclasses
+
 import pytest
 
 import cmd2
@@ -21,7 +19,7 @@ from cmd2.parsing import (
 
 @pytest.fixture
 def parser():
-    parser = StatementParser(
+    return StatementParser(
         terminators=[';', '&'],
         multiline_commands=['multiline'],
         aliases={
@@ -33,16 +31,14 @@ def parser():
         },
         shortcuts={'?': 'help', '!': 'shell'},
     )
-    return parser
 
 
 @pytest.fixture
 def default_parser():
-    parser = StatementParser()
-    return parser
+    return StatementParser()
 
 
-def test_parse_empty_string(parser):
+def test_parse_empty_string(parser) -> None:
     line = ''
     statement = parser.parse(line)
     assert statement == ''
@@ -60,7 +56,7 @@ def test_parse_empty_string(parser):
     assert statement.argv == statement.arg_list
 
 
-def test_parse_empty_string_default(default_parser):
+def test_parse_empty_string_default(default_parser) -> None:
     line = ''
     statement = default_parser.parse(line)
     assert statement == ''
@@ -79,7 +75,7 @@ def test_parse_empty_string_default(default_parser):
 
 
 @pytest.mark.parametrize(
-    'line,tokens',
+    ('line', 'tokens'),
     [
         ('command', ['command']),
         (constants.COMMENT_CHAR + 'comment', []),
@@ -91,13 +87,13 @@ def test_parse_empty_string_default(default_parser):
         ('help|less', ['help', '|', 'less']),
     ],
 )
-def test_tokenize_default(default_parser, line, tokens):
+def test_tokenize_default(default_parser, line, tokens) -> None:
     tokens_to_test = default_parser.tokenize(line)
     assert tokens_to_test == tokens
 
 
 @pytest.mark.parametrize(
-    'line,tokens',
+    ('line', 'tokens'),
     [
         ('command', ['command']),
         ('# comment', []),
@@ -112,20 +108,21 @@ def test_tokenize_default(default_parser, line, tokens):
         ('l|less', ['shell', 'ls', '-al', '|', 'less']),
     ],
 )
-def test_tokenize(parser, line, tokens):
+def test_tokenize(parser, line, tokens) -> None:
     tokens_to_test = parser.tokenize(line)
     assert tokens_to_test == tokens
 
 
-def test_tokenize_unclosed_quotes(parser):
+def test_tokenize_unclosed_quotes(parser) -> None:
     with pytest.raises(exceptions.Cmd2ShlexError):
         _ = parser.tokenize('command with "unclosed quotes')
 
 
 @pytest.mark.parametrize(
-    'tokens,command,args', [([], '', ''), (['command'], 'command', ''), (['command', 'arg1', 'arg2'], 'command', 'arg1 arg2')]
+    ('tokens', 'command', 'args'),
+    [([], '', ''), (['command'], 'command', ''), (['command', 'arg1', 'arg2'], 'command', 'arg1 arg2')],
 )
-def test_command_and_args(parser, tokens, command, args):
+def test_command_and_args(parser, tokens, command, args) -> None:
     (parsed_command, parsed_args) = parser._command_and_args(tokens)
     assert command == parsed_command
     assert args == parsed_args
@@ -139,7 +136,7 @@ def test_command_and_args(parser, tokens, command, args):
         "'one word'",
     ],
 )
-def test_parse_single_word(parser, line):
+def test_parse_single_word(parser, line) -> None:
     statement = parser.parse(line)
     assert statement.command == line
     assert statement == ''
@@ -157,7 +154,7 @@ def test_parse_single_word(parser, line):
 
 
 @pytest.mark.parametrize(
-    'line,terminator',
+    ('line', 'terminator'),
     [
         ('termbare;', ';'),
         ('termbare ;', ';'),
@@ -165,7 +162,7 @@ def test_parse_single_word(parser, line):
         ('termbare &', '&'),
     ],
 )
-def test_parse_word_plus_terminator(parser, line, terminator):
+def test_parse_word_plus_terminator(parser, line, terminator) -> None:
     statement = parser.parse(line)
     assert statement.command == 'termbare'
     assert statement == ''
@@ -176,7 +173,7 @@ def test_parse_word_plus_terminator(parser, line, terminator):
 
 
 @pytest.mark.parametrize(
-    'line,terminator',
+    ('line', 'terminator'),
     [
         ('termbare;  suffx', ';'),
         ('termbare ;suffx', ';'),
@@ -184,7 +181,7 @@ def test_parse_word_plus_terminator(parser, line, terminator):
         ('termbare &suffx', '&'),
     ],
 )
-def test_parse_suffix_after_terminator(parser, line, terminator):
+def test_parse_suffix_after_terminator(parser, line, terminator) -> None:
     statement = parser.parse(line)
     assert statement.command == 'termbare'
     assert statement == ''
@@ -196,7 +193,7 @@ def test_parse_suffix_after_terminator(parser, line, terminator):
     assert statement.expanded_command_line == statement.command + statement.terminator + ' ' + statement.suffix
 
 
-def test_parse_command_with_args(parser):
+def test_parse_command_with_args(parser) -> None:
     line = 'command with args'
     statement = parser.parse(line)
     assert statement.command == 'command'
@@ -206,7 +203,7 @@ def test_parse_command_with_args(parser):
     assert statement.arg_list == statement.argv[1:]
 
 
-def test_parse_command_with_quoted_args(parser):
+def test_parse_command_with_quoted_args(parser) -> None:
     line = 'command with "quoted args" and "some not"'
     statement = parser.parse(line)
     assert statement.command == 'command'
@@ -216,7 +213,7 @@ def test_parse_command_with_quoted_args(parser):
     assert statement.arg_list == ['with', '"quoted args"', 'and', '"some not"']
 
 
-def test_parse_command_with_args_terminator_and_suffix(parser):
+def test_parse_command_with_args_terminator_and_suffix(parser) -> None:
     line = 'command with args and terminator; and suffix'
     statement = parser.parse(line)
     assert statement.command == 'command'
@@ -228,7 +225,7 @@ def test_parse_command_with_args_terminator_and_suffix(parser):
     assert statement.suffix == 'and suffix'
 
 
-def test_parse_comment(parser):
+def test_parse_comment(parser) -> None:
     statement = parser.parse(constants.COMMENT_CHAR + ' this is all a comment')
     assert statement.command == ''
     assert statement == ''
@@ -237,7 +234,7 @@ def test_parse_comment(parser):
     assert not statement.arg_list
 
 
-def test_parse_embedded_comment_char(parser):
+def test_parse_embedded_comment_char(parser) -> None:
     command_str = 'hi ' + constants.COMMENT_CHAR + ' not a comment'
     statement = parser.parse(command_str)
     assert statement.command == 'hi'
@@ -254,7 +251,7 @@ def test_parse_embedded_comment_char(parser):
         'simple|piped',
     ],
 )
-def test_parse_simple_pipe(parser, line):
+def test_parse_simple_pipe(parser, line) -> None:
     statement = parser.parse(line)
     assert statement.command == 'simple'
     assert statement == ''
@@ -265,7 +262,7 @@ def test_parse_simple_pipe(parser, line):
     assert statement.expanded_command_line == statement.command + ' | ' + statement.pipe_to
 
 
-def test_parse_double_pipe_is_not_a_pipe(parser):
+def test_parse_double_pipe_is_not_a_pipe(parser) -> None:
     line = 'double-pipe || is not a pipe'
     statement = parser.parse(line)
     assert statement.command == 'double-pipe'
@@ -276,7 +273,7 @@ def test_parse_double_pipe_is_not_a_pipe(parser):
     assert not statement.pipe_to
 
 
-def test_parse_complex_pipe(parser):
+def test_parse_complex_pipe(parser) -> None:
     line = 'command with args, terminator&sufx | piped'
     statement = parser.parse(line)
     assert statement.command == 'command'
@@ -290,7 +287,7 @@ def test_parse_complex_pipe(parser):
 
 
 @pytest.mark.parametrize(
-    'line,output',
+    ('line', 'output'),
     [
         ('help > out.txt', '>'),
         ('help>out.txt', '>'),
@@ -298,7 +295,7 @@ def test_parse_complex_pipe(parser):
         ('help>>out.txt', '>>'),
     ],
 )
-def test_parse_redirect(parser, line, output):
+def test_parse_redirect(parser, line, output) -> None:
     statement = parser.parse(line)
     assert statement.command == 'help'
     assert statement == ''
@@ -315,8 +312,8 @@ def test_parse_redirect(parser, line, output):
         'python-cmd2/afile.txt',
     ],
 )  # without dashes  # with dashes in path
-def test_parse_redirect_with_args(parser, dest):
-    line = 'output into > {}'.format(dest)
+def test_parse_redirect_with_args(parser, dest) -> None:
+    line = f'output into > {dest}'
     statement = parser.parse(line)
     assert statement.command == 'output'
     assert statement == 'into'
@@ -327,7 +324,7 @@ def test_parse_redirect_with_args(parser, dest):
     assert statement.output_to == dest
 
 
-def test_parse_redirect_append(parser):
+def test_parse_redirect_append(parser) -> None:
     line = 'output appended to >> /tmp/afile.txt'
     statement = parser.parse(line)
     assert statement.command == 'output'
@@ -339,7 +336,7 @@ def test_parse_redirect_append(parser):
     assert statement.output_to == '/tmp/afile.txt'
 
 
-def test_parse_pipe_then_redirect(parser):
+def test_parse_pipe_then_redirect(parser) -> None:
     line = 'output into;sufx | pipethrume plz > afile.txt'
     statement = parser.parse(line)
     assert statement.command == 'output'
@@ -354,7 +351,7 @@ def test_parse_pipe_then_redirect(parser):
     assert statement.output_to == ''
 
 
-def test_parse_multiple_pipes(parser):
+def test_parse_multiple_pipes(parser) -> None:
     line = 'output into;sufx | pipethrume plz | grep blah'
     statement = parser.parse(line)
     assert statement.command == 'output'
@@ -369,7 +366,7 @@ def test_parse_multiple_pipes(parser):
     assert statement.output_to == ''
 
 
-def test_redirect_then_pipe(parser):
+def test_redirect_then_pipe(parser) -> None:
     line = 'help alias > file.txt | grep blah'
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -384,7 +381,7 @@ def test_redirect_then_pipe(parser):
     assert statement.output_to == 'file.txt'
 
 
-def test_append_then_pipe(parser):
+def test_append_then_pipe(parser) -> None:
     line = 'help alias >> file.txt | grep blah'
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -399,7 +396,7 @@ def test_append_then_pipe(parser):
     assert statement.output_to == 'file.txt'
 
 
-def test_append_then_redirect(parser):
+def test_append_then_redirect(parser) -> None:
     line = 'help alias >> file.txt > file2.txt'
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -414,7 +411,7 @@ def test_append_then_redirect(parser):
     assert statement.output_to == 'file.txt'
 
 
-def test_redirect_then_append(parser):
+def test_redirect_then_append(parser) -> None:
     line = 'help alias > file.txt >> file2.txt'
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -429,7 +426,7 @@ def test_redirect_then_append(parser):
     assert statement.output_to == 'file.txt'
 
 
-def test_redirect_to_quoted_string(parser):
+def test_redirect_to_quoted_string(parser) -> None:
     line = 'help alias > "file.txt"'
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -444,7 +441,7 @@ def test_redirect_to_quoted_string(parser):
     assert statement.output_to == '"file.txt"'
 
 
-def test_redirect_to_single_quoted_string(parser):
+def test_redirect_to_single_quoted_string(parser) -> None:
     line = "help alias > 'file.txt'"
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -459,7 +456,7 @@ def test_redirect_to_single_quoted_string(parser):
     assert statement.output_to == "'file.txt'"
 
 
-def test_redirect_to_empty_quoted_string(parser):
+def test_redirect_to_empty_quoted_string(parser) -> None:
     line = 'help alias > ""'
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -474,7 +471,7 @@ def test_redirect_to_empty_quoted_string(parser):
     assert statement.output_to == ''
 
 
-def test_redirect_to_empty_single_quoted_string(parser):
+def test_redirect_to_empty_single_quoted_string(parser) -> None:
     line = "help alias > ''"
     statement = parser.parse(line)
     assert statement.command == 'help'
@@ -489,7 +486,7 @@ def test_redirect_to_empty_single_quoted_string(parser):
     assert statement.output_to == ''
 
 
-def test_parse_output_to_paste_buffer(parser):
+def test_parse_output_to_paste_buffer(parser) -> None:
     line = 'output to paste buffer >> '
     statement = parser.parse(line)
     assert statement.command == 'output'
@@ -500,10 +497,11 @@ def test_parse_output_to_paste_buffer(parser):
     assert statement.output == '>>'
 
 
-def test_parse_redirect_inside_terminator(parser):
-    """The terminator designates the end of the commmand/arguments portion.
+def test_parse_redirect_inside_terminator(parser) -> None:
+    """The terminator designates the end of the command/arguments portion.
     If a redirector occurs before a terminator, then it will be treated as
-    part of the arguments and not as a redirector."""
+    part of the arguments and not as a redirector.
+    """
     line = 'has > inside;'
     statement = parser.parse(line)
     assert statement.command == 'has'
@@ -515,7 +513,7 @@ def test_parse_redirect_inside_terminator(parser):
 
 
 @pytest.mark.parametrize(
-    'line,terminator',
+    ('line', 'terminator'),
     [
         ('multiline with | inside;', ';'),
         ('multiline with | inside ;', ';'),
@@ -527,7 +525,7 @@ def test_parse_redirect_inside_terminator(parser):
         ('multiline with | inside &; &;', '&'),
     ],
 )
-def test_parse_multiple_terminators(parser, line, terminator):
+def test_parse_multiple_terminators(parser, line, terminator) -> None:
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
     assert statement == 'with | inside'
@@ -537,7 +535,7 @@ def test_parse_multiple_terminators(parser, line, terminator):
     assert statement.terminator == terminator
 
 
-def test_parse_unfinished_multiliine_command(parser):
+def test_parse_unfinished_multiliine_command(parser) -> None:
     line = 'multiline has > inside an unfinished command'
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
@@ -549,7 +547,7 @@ def test_parse_unfinished_multiliine_command(parser):
     assert statement.terminator == ''
 
 
-def test_parse_basic_multiline_command(parser):
+def test_parse_basic_multiline_command(parser) -> None:
     line = 'multiline foo\nbar\n\n'
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
@@ -563,7 +561,7 @@ def test_parse_basic_multiline_command(parser):
 
 
 @pytest.mark.parametrize(
-    'line,terminator',
+    ('line', 'terminator'),
     [
         ('multiline has > inside;', ';'),
         ('multiline has > inside;;;', ';'),
@@ -572,7 +570,7 @@ def test_parse_basic_multiline_command(parser):
         ('multiline has > inside & &', '&'),
     ],
 )
-def test_parse_multiline_command_ignores_redirectors_within_it(parser, line, terminator):
+def test_parse_multiline_command_ignores_redirectors_within_it(parser, line, terminator) -> None:
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
     assert statement == 'has > inside'
@@ -582,7 +580,7 @@ def test_parse_multiline_command_ignores_redirectors_within_it(parser, line, ter
     assert statement.terminator == terminator
 
 
-def test_parse_multiline_terminated_by_empty_line(parser):
+def test_parse_multiline_terminated_by_empty_line(parser) -> None:
     line = 'multiline command ends\n\n'
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
@@ -595,7 +593,7 @@ def test_parse_multiline_terminated_by_empty_line(parser):
 
 
 @pytest.mark.parametrize(
-    'line,terminator',
+    ('line', 'terminator'),
     [
         ('multiline command "with\nembedded newline";', ';'),
         ('multiline command "with\nembedded newline";;;', ';'),
@@ -605,7 +603,7 @@ def test_parse_multiline_terminated_by_empty_line(parser):
         ('multiline command "with\nembedded newline"\n\n', '\n'),
     ],
 )
-def test_parse_multiline_with_embedded_newline(parser, line, terminator):
+def test_parse_multiline_with_embedded_newline(parser, line, terminator) -> None:
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
     assert statement.command == 'multiline'
@@ -616,7 +614,7 @@ def test_parse_multiline_with_embedded_newline(parser, line, terminator):
     assert statement.terminator == terminator
 
 
-def test_parse_multiline_ignores_terminators_in_quotes(parser):
+def test_parse_multiline_ignores_terminators_in_quotes(parser) -> None:
     line = 'multiline command "with term; ends" now\n\n'
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
@@ -628,7 +626,7 @@ def test_parse_multiline_ignores_terminators_in_quotes(parser):
     assert statement.terminator == '\n'
 
 
-def test_parse_command_with_unicode_args(parser):
+def test_parse_command_with_unicode_args(parser) -> None:
     line = 'drink café'
     statement = parser.parse(line)
     assert statement.command == 'drink'
@@ -638,7 +636,7 @@ def test_parse_command_with_unicode_args(parser):
     assert statement.arg_list == statement.argv[1:]
 
 
-def test_parse_unicode_command(parser):
+def test_parse_unicode_command(parser) -> None:
     line = 'café au lait'
     statement = parser.parse(line)
     assert statement.command == 'café'
@@ -648,7 +646,7 @@ def test_parse_unicode_command(parser):
     assert statement.arg_list == statement.argv[1:]
 
 
-def test_parse_redirect_to_unicode_filename(parser):
+def test_parse_redirect_to_unicode_filename(parser) -> None:
     line = 'dir home > café'
     statement = parser.parse(line)
     assert statement.command == 'dir'
@@ -660,12 +658,12 @@ def test_parse_redirect_to_unicode_filename(parser):
     assert statement.output_to == 'café'
 
 
-def test_parse_unclosed_quotes(parser):
+def test_parse_unclosed_quotes(parser) -> None:
     with pytest.raises(exceptions.Cmd2ShlexError):
         _ = parser.tokenize("command with 'unclosed quotes")
 
 
-def test_empty_statement_raises_exception():
+def test_empty_statement_raises_exception() -> None:
     app = cmd2.Cmd()
     with pytest.raises(exceptions.EmptyStatement):
         app._complete_statement('')
@@ -675,7 +673,7 @@ def test_empty_statement_raises_exception():
 
 
 @pytest.mark.parametrize(
-    'line,command,args',
+    ('line', 'command', 'args'),
     [
         ('helpalias', 'help', ''),
         ('helpalias mycommand', 'help', 'mycommand'),
@@ -686,14 +684,14 @@ def test_empty_statement_raises_exception():
         ('l', 'shell', 'ls -al'),
     ],
 )
-def test_parse_alias_and_shortcut_expansion(parser, line, command, args):
+def test_parse_alias_and_shortcut_expansion(parser, line, command, args) -> None:
     statement = parser.parse(line)
     assert statement.command == command
     assert statement == args
     assert statement.args == statement
 
 
-def test_parse_alias_on_multiline_command(parser):
+def test_parse_alias_on_multiline_command(parser) -> None:
     line = 'anothermultiline has > inside an unfinished command'
     statement = parser.parse(line)
     assert statement.multiline_command == 'multiline'
@@ -704,7 +702,7 @@ def test_parse_alias_on_multiline_command(parser):
 
 
 @pytest.mark.parametrize(
-    'line,output',
+    ('line', 'output'),
     [
         ('helpalias > out.txt', '>'),
         ('helpalias>out.txt', '>'),
@@ -712,7 +710,7 @@ def test_parse_alias_on_multiline_command(parser):
         ('helpalias>>out.txt', '>>'),
     ],
 )
-def test_parse_alias_redirection(parser, line, output):
+def test_parse_alias_redirection(parser, line, output) -> None:
     statement = parser.parse(line)
     assert statement.command == 'help'
     assert statement == ''
@@ -728,7 +726,7 @@ def test_parse_alias_redirection(parser, line, output):
         'helpalias|less',
     ],
 )
-def test_parse_alias_pipe(parser, line):
+def test_parse_alias_pipe(parser, line) -> None:
     statement = parser.parse(line)
     assert statement.command == 'help'
     assert statement == ''
@@ -747,7 +745,7 @@ def test_parse_alias_pipe(parser, line):
         'helpalias ;; ;',
     ],
 )
-def test_parse_alias_terminator_no_whitespace(parser, line):
+def test_parse_alias_terminator_no_whitespace(parser, line) -> None:
     statement = parser.parse(line)
     assert statement.command == 'help'
     assert statement == ''
@@ -755,7 +753,7 @@ def test_parse_alias_terminator_no_whitespace(parser, line):
     assert statement.terminator == ';'
 
 
-def test_parse_command_only_command_and_args(parser):
+def test_parse_command_only_command_and_args(parser) -> None:
     line = 'help history'
     statement = parser.parse_command_only(line)
     assert statement == 'history'
@@ -772,7 +770,7 @@ def test_parse_command_only_command_and_args(parser):
     assert statement.output_to == ''
 
 
-def test_parse_command_only_strips_line(parser):
+def test_parse_command_only_strips_line(parser) -> None:
     line = '  help history  '
     statement = parser.parse_command_only(line)
     assert statement == 'history'
@@ -789,7 +787,7 @@ def test_parse_command_only_strips_line(parser):
     assert statement.output_to == ''
 
 
-def test_parse_command_only_expands_alias(parser):
+def test_parse_command_only_expands_alias(parser) -> None:
     line = 'fake foobar.py "somebody.py'
     statement = parser.parse_command_only(line)
     assert statement == 'foobar.py "somebody.py'
@@ -806,7 +804,7 @@ def test_parse_command_only_expands_alias(parser):
     assert statement.output_to == ''
 
 
-def test_parse_command_only_expands_shortcuts(parser):
+def test_parse_command_only_expands_shortcuts(parser) -> None:
     line = '!cat foobar.txt'
     statement = parser.parse_command_only(line)
     assert statement == 'cat foobar.txt'
@@ -824,7 +822,7 @@ def test_parse_command_only_expands_shortcuts(parser):
     assert statement.output_to == ''
 
 
-def test_parse_command_only_quoted_args(parser):
+def test_parse_command_only_quoted_args(parser) -> None:
     line = 'l "/tmp/directory with spaces/doit.sh"'
     statement = parser.parse_command_only(line)
     assert statement == 'ls -al "/tmp/directory with spaces/doit.sh"'
@@ -842,8 +840,27 @@ def test_parse_command_only_quoted_args(parser):
     assert statement.output_to == ''
 
 
+def test_parse_command_only_unclosed_quote(parser) -> None:
+    # Quoted trailing spaces will be preserved
+    line = 'command with unclosed "quote     '
+    statement = parser.parse_command_only(line)
+    assert statement == 'with unclosed "quote     '
+    assert statement.args == statement
+    assert statement.arg_list == []
+    assert statement.command == 'command'
+    assert statement.command_and_args == line
+    assert statement.multiline_command == ''
+    assert statement.raw == line
+    assert statement.multiline_command == ''
+    assert statement.terminator == ''
+    assert statement.suffix == ''
+    assert statement.pipe_to == ''
+    assert statement.output == ''
+    assert statement.output_to == ''
+
+
 @pytest.mark.parametrize(
-    'line,args',
+    ('line', 'args'),
     [
         ('helpalias > out.txt', '> out.txt'),
         ('helpalias>out.txt', '>out.txt'),
@@ -855,7 +872,7 @@ def test_parse_command_only_quoted_args(parser):
         ('help; ;;', '; ;;'),
     ],
 )
-def test_parse_command_only_specialchars(parser, line, args):
+def test_parse_command_only_specialchars(parser, line, args) -> None:
     statement = parser.parse_command_only(line)
     assert statement == args
     assert statement.args == args
@@ -886,7 +903,7 @@ def test_parse_command_only_specialchars(parser, line, args):
         '|',
     ],
 )
-def test_parse_command_only_empty(parser, line):
+def test_parse_command_only_empty(parser, line) -> None:
     statement = parser.parse_command_only(line)
     assert statement == ''
     assert statement.args == statement
@@ -903,7 +920,7 @@ def test_parse_command_only_empty(parser, line):
     assert statement.output_to == ''
 
 
-def test_parse_command_only_multiline(parser):
+def test_parse_command_only_multiline(parser) -> None:
     line = 'multiline with partially "open quotes and no terminator'
     statement = parser.parse_command_only(line)
     assert statement.command == 'multiline'
@@ -913,7 +930,7 @@ def test_parse_command_only_multiline(parser):
     assert statement.args == statement
 
 
-def test_statement_initialization():
+def test_statement_initialization() -> None:
     string = 'alias'
     statement = cmd2.Statement(string)
     assert string == statement
@@ -933,19 +950,19 @@ def test_statement_initialization():
     assert statement.output_to == ''
 
 
-def test_statement_is_immutable():
+def test_statement_is_immutable() -> None:
     string = 'foo'
     statement = cmd2.Statement(string)
     assert string == statement
     assert statement.args == statement
     assert statement.raw == ''
-    with pytest.raises(attr.exceptions.FrozenInstanceError):
+    with pytest.raises(dataclasses.FrozenInstanceError):
         statement.args = 'bar'
-    with pytest.raises(attr.exceptions.FrozenInstanceError):
+    with pytest.raises(dataclasses.FrozenInstanceError):
         statement.raw = 'baz'
 
 
-def test_statement_as_dict(parser):
+def test_statement_as_dict(parser) -> None:
     # Make sure to_dict() results can be restored to identical Statement
     statement = parser.parse("!ls > out.txt")
     assert statement == Statement.from_dict(statement.to_dict())
@@ -965,46 +982,54 @@ def test_statement_as_dict(parser):
         Statement.from_dict(statement_dict)
 
 
-def test_is_valid_command_invalid(mocker, parser):
+def test_is_valid_command_invalid(mocker, parser) -> None:
     # Non-string command
-    # noinspection PyTypeChecker
     valid, errmsg = parser.is_valid_command(5)
-    assert not valid and 'must be a string' in errmsg
+    assert not valid
+    assert 'must be a string' in errmsg
 
     mock = mocker.MagicMock()
     valid, errmsg = parser.is_valid_command(mock)
-    assert not valid and 'must be a string' in errmsg
+    assert not valid
+    assert 'must be a string' in errmsg
 
     # Empty command
     valid, errmsg = parser.is_valid_command('')
-    assert not valid and 'cannot be an empty string' in errmsg
+    assert not valid
+    assert 'cannot be an empty string' in errmsg
 
     # Start with the comment character
     valid, errmsg = parser.is_valid_command(constants.COMMENT_CHAR)
-    assert not valid and 'cannot start with the comment character' in errmsg
+    assert not valid
+    assert 'cannot start with the comment character' in errmsg
 
     # Starts with shortcut
     valid, errmsg = parser.is_valid_command('!ls')
-    assert not valid and 'cannot start with a shortcut' in errmsg
+    assert not valid
+    assert 'cannot start with a shortcut' in errmsg
 
     # Contains whitespace
     valid, errmsg = parser.is_valid_command('shell ls')
-    assert not valid and 'cannot contain: whitespace, quotes,' in errmsg
+    assert not valid
+    assert 'cannot contain: whitespace, quotes,' in errmsg
 
     # Contains a quote
     valid, errmsg = parser.is_valid_command('"shell"')
-    assert not valid and 'cannot contain: whitespace, quotes,' in errmsg
+    assert not valid
+    assert 'cannot contain: whitespace, quotes,' in errmsg
 
     # Contains a redirector
     valid, errmsg = parser.is_valid_command('>shell')
-    assert not valid and 'cannot contain: whitespace, quotes,' in errmsg
+    assert not valid
+    assert 'cannot contain: whitespace, quotes,' in errmsg
 
     # Contains a terminator
     valid, errmsg = parser.is_valid_command(';shell')
-    assert not valid and 'cannot contain: whitespace, quotes,' in errmsg
+    assert not valid
+    assert 'cannot contain: whitespace, quotes,' in errmsg
 
 
-def test_is_valid_command_valid(parser):
+def test_is_valid_command_valid(parser) -> None:
     # Valid command
     valid, errmsg = parser.is_valid_command('shell')
     assert valid
@@ -1016,7 +1041,7 @@ def test_is_valid_command_valid(parser):
     assert not errmsg
 
 
-def test_macro_normal_arg_pattern():
+def test_macro_normal_arg_pattern() -> None:
     # This pattern matches digits surrounded by exactly 1 brace on a side and 1 or more braces on the opposite side
     from cmd2.parsing import (
         MacroArg,
@@ -1070,7 +1095,7 @@ def test_macro_normal_arg_pattern():
     assert not matches
 
 
-def test_macro_escaped_arg_pattern():
+def test_macro_escaped_arg_pattern() -> None:
     # This pattern matches digits surrounded by 2 or more braces on both sides
     from cmd2.parsing import (
         MacroArg,
